@@ -3,7 +3,7 @@
  * \brief Property class declaration
  * \see mlt_property_s
  *
- * Copyright (C) 2003-2014 Meltytech, LLC
+ * Copyright (C) 2003-2018 Meltytech, LLC
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -30,13 +30,19 @@
 #include <sys/param.h>
 #endif
 
-#if defined(__GLIBC__) || defined(__APPLE__) || (__FreeBSD_version >= 900506)
-#include <locale.h>
+#if (defined(__GLIBC__) && !defined(__APPLE__)) || defined(HAVE_LOCALE_H)
+#  include <locale.h>
+#elif defined(__APPLE__) || (defined(__FreeBSD_version) && __FreeBSD_version >= 900506)
+#  include <xlocale.h>
+#elif defined(__OpenBSD__)
+/* XXX matches __nop_locale glue in libc++ */
+typedef void* locale_t;
 #else
 typedef char* locale_t;
 #endif
 
 extern mlt_property mlt_property_init( );
+extern void mlt_property_clear( mlt_property self );
 extern int mlt_property_set_int( mlt_property self, int value );
 extern int mlt_property_set_double( mlt_property self, double value );
 extern int mlt_property_set_position( mlt_property self, mlt_position value );
@@ -47,7 +53,9 @@ extern int mlt_property_get_int( mlt_property self, double fps, locale_t );
 extern double mlt_property_get_double( mlt_property self, double fps, locale_t );
 extern mlt_position mlt_property_get_position( mlt_property self, double fps, locale_t );
 extern int64_t mlt_property_get_int64( mlt_property self );
+extern char *mlt_property_get_string_tf( mlt_property self, mlt_time_format );
 extern char *mlt_property_get_string( mlt_property self );
+extern char *mlt_property_get_string_l_tf( mlt_property self, locale_t, mlt_time_format );
 extern char *mlt_property_get_string_l( mlt_property self, locale_t );
 extern void *mlt_property_get_data( mlt_property self, int *length );
 extern void mlt_property_close( mlt_property self );
